@@ -107,7 +107,7 @@ class KubernetesBackend:
                 name=name,
                 grace_period_seconds=0,
                 propagation_policy="Background",
-                body=V1DeleteOptions(propagation_policy='Background')
+                body=V1DeleteOptions(propagation_policy="Background"),
             )
 
 
@@ -162,7 +162,6 @@ def get_simulation_job(cfg: KubernetesJobConfig) -> Job:
                     containers=[
                         get_container(cfg.redis_config),
                         get_container(cfg.scheduler_config),
-                        get_container(cfg.scheduler_worker_config),
                         get_container(cfg.simulation_config),
                     ],
                     volumes=[
