@@ -239,7 +239,6 @@ class KubernetesJobConfig:
     name: str
     redis_config: KubernetesContainer
     scheduler_config: KubernetesContainer
-    scheduler_worker_config: KubernetesContainer
     simulation_config: KubernetesContainer
     annotations: List[Label] = field(default_factory=list)
     labels: List[Label] = field(default_factory=list)
@@ -257,7 +256,6 @@ class KubernetesJobConfig:
         for mount_point in (
             self.redis_config.mount_points
             + self.scheduler_config.mount_points
-            + self.scheduler_worker_config.mount_points
             + self.simulation_config.mount_points
         ):
             if mount_point not in mount_points:
@@ -277,9 +275,6 @@ class KubernetesJobConfig:
             name=name,
             redis_config=KubernetesContainer.from_dict(cfg["REDIS"]),
             scheduler_config=KubernetesContainer.from_dict(cfg["SCHEDULER"]),
-            scheduler_worker_config=KubernetesContainer.from_dict(
-                cfg["SCHEDULER_WORKER"]
-            ),
             simulation_config=KubernetesContainer.from_dict(cfg["SIMULATION"]),
             host_aliases=[
                 HostAlias(ip_address, hostnames)
